@@ -175,7 +175,7 @@ void AppMenuModel::onActiveWindowChanged(WId id)
     if (KWindowSystem::isPlatformX11()) {
         auto *c = QX11Info::connection();
 
-        auto getWindowPropertyString = [c, this](WId id, const QByteArray &name) -> QByteArray {
+        auto getWindowPropertyString = [c](WId id, const QByteArray &name) -> QByteArray {
             QByteArray value;
             if (!s_atoms.contains(name)) {
                 const xcb_intern_atom_cookie_t atomCookie = xcb_intern_atom(c, false, name.length(), name.constData());
@@ -299,7 +299,7 @@ QVariant AppMenuModel::data(const QModelIndex &index, int role) const
     if (role == MenuRole) { // TODO this should be Qt::DisplayRole
         return actions.at(row)->text();
     } else if (role == ActionRole) {
-        return qVariantFromValue((void *) actions.at(row));
+        return QVariant::fromValue((void *) actions.at(row));
     }
 
     return QVariant();
