@@ -38,6 +38,7 @@
 #include <KDesktopFile>
 #include <KFileItemActions>
 #include <KFileItemListProperties>
+#include <KFileUtils>
 #include <KJobWidgets>
 #include <KLocalizedString>
 #include <KProtocolManager>
@@ -110,7 +111,7 @@ void IconApplet::populate()
     connect(statJob, &KIO::StatJob::finished, this, [=] {
         QString desiredDesktopFileName = m_url.fileName();
 
-        // in doubt, just encode the entire URL, e.g. http://www.kde.org/ has no filename
+        // in doubt, just encode the entire URL, e.g. https://www.kde.org/ has no filename
         if (desiredDesktopFileName.isEmpty()) {
             desiredDesktopFileName = KIO::encodeFileName(m_url.toDisplayString());
         }
@@ -121,9 +122,9 @@ void IconApplet::populate()
         }
 
         QString backingDesktopFile = plasmaIconsFolderPath + QLatin1Char('/');
-        // KIO::suggestName always appends a suffix, i.e. it expects that we already know the file already exists
+        // KFileUtils::suggestName always appends a suffix, i.e. it expects that we already know the file already exists
         if (QFileInfo::exists(backingDesktopFile + desiredDesktopFileName)) {
-            desiredDesktopFileName = KIO::suggestName(QUrl::fromLocalFile(plasmaIconsFolderPath), desiredDesktopFileName);
+            desiredDesktopFileName = KFileUtils::suggestName(QUrl::fromLocalFile(plasmaIconsFolderPath), desiredDesktopFileName);
         }
         backingDesktopFile.append(desiredDesktopFileName);
 
@@ -368,28 +369,30 @@ QList<QAction *> IconApplet::contextualActions()
     if (desktopFile.hasLinkType()) {
         const QUrl linkUrl = QUrl(desktopFile.readUrl());
 
-        if (m_openWithActions.isEmpty()) {
-            if (!m_fileItemActions) {
-                m_fileItemActions = new KFileItemActions(this);
+        if (linkUrl.isValid() && !linkUrl.scheme().isEmpty()) {
+            if (m_openWithActions.isEmpty()) {
+                if (!m_fileItemActions) {
+                    m_fileItemActions = new KFileItemActions(this);
+                }
+                KFileItemListProperties itemProperties(KFileItemList({KFileItem(linkUrl)}));
+                m_fileItemActions->setItemListProperties(itemProperties);
+
+                if (!m_openWithMenu) {
+                    m_openWithMenu.reset(new QMenu());
+                }
+                m_openWithMenu->clear();
+                m_fileItemActions->addOpenWithActionsTo(m_openWithMenu.data());
+
+                m_openWithActions = m_openWithMenu->actions();
             }
-            KFileItemListProperties itemProperties(KFileItemList({KFileItem(linkUrl)}));
-            m_fileItemActions->setItemListProperties(itemProperties);
 
-            if (!m_openWithMenu) {
-                m_openWithMenu.reset(new QMenu());
-            }
-            m_openWithMenu->clear();
-            m_fileItemActions->addOpenWithActionsTo(m_openWithMenu.data());
-
-            m_openWithActions = m_openWithMenu->actions();
-        }
-
-        if (!m_openContainingFolderAction) {
-            if (KProtocolManager::supportsListing(linkUrl)) {
-                m_openContainingFolderAction = new QAction(QIcon::fromTheme(QStringLiteral("document-open-folder")), i18n("Open Containing Folder"), this);
-                connect(m_openContainingFolderAction, &QAction::triggered, this, [this, linkUrl] {
-                    KIO::highlightInFileManager({linkUrl});
-                });
+            if (!m_openContainingFolderAction) {
+                if (KProtocolManager::supportsListing(linkUrl)) {
+                    m_openContainingFolderAction = new QAction(QIcon::fromTheme(QStringLiteral("document-open-folder")), i18n("Open Containing Folder"), this);
+                    connect(m_openContainingFolderAction, &QAction::triggered, this, [ linkUrl] {
+                        KIO::highlightInFileManager({linkUrl});
+                    });
+                }
             }
         }
     }
