@@ -105,7 +105,7 @@ QVariant RootModel::data(const QModelIndex& index, int role) const
                     actionList << model->actions();
                     actionList << Kicker::createSeparatorActionItem();
                     actionList << Kicker::createActionItem(i18n("Hide %1",
-                        group->name()), QStringLiteral("hideCategory"));
+                        group->name()), QStringLiteral("view-hidden"), QStringLiteral("hideCategory"));
                     return actionList;
                 }
             }
@@ -394,7 +394,7 @@ void RootModel::refresh()
     int separatorPosition = 0;
 
     if (allModel) {
-        m_entryList.prepend(new GroupEntry(this, i18n("All Applications"), QString(), allModel));
+        m_entryList.prepend(new GroupEntry(this, i18n("All Applications"), QString("applications-all"), allModel));
         ++separatorPosition;
     }
 
