@@ -25,10 +25,12 @@
 #include <QQmlEngine>
 
 #include "sessionsmodel.h"
+#include <sessionmanagement.h>
 
 void SessionsPrivatePlugin::registerTypes(const char *uri)
 {
     Q_ASSERT(uri == QLatin1String("org.kde.plasma.private.sessions"));
 
+    qmlRegisterType<SessionManagement>(uri, 2, 0, "SessionManagement");
     qmlRegisterType<SessionsModel>(uri, 2, 0, "SessionsModel");
 }
