@@ -212,7 +212,7 @@ QList <QObject *>  WidgetExplorer::widgetsMenuActions()
     WidgetAction *action = nullptr;
 
     if (KAuthorized::authorize(QStringLiteral("ghns"))) {
-        action = new WidgetAction(QIcon::fromTheme(QStringLiteral("applications-internet")),
+        action = new WidgetAction(QIcon::fromTheme(QStringLiteral("internet-services")),
                                       i18n("Download New Plasma Widgets"), this);
         connect(action, &QAction::triggered, this, &WidgetExplorer::downloadWidgets);
         actionList << action;
