@@ -21,7 +21,7 @@
 #define STATUSNOTIFIERITEMJOB_H
 
 // Qt
-#include <QtWidgets/QMenu>
+#include <QMenu>
 
 // own
 #include "statusnotifieritemsource.h"
@@ -37,7 +37,7 @@ class StatusNotifierItemJob : public Plasma::ServiceJob
     Q_OBJECT
 
 public:
-    StatusNotifierItemJob(StatusNotifierItemSource *source, const QString &operation, QMap<QString, QVariant> &parameters, QObject *parent = NULL);
+    StatusNotifierItemJob(StatusNotifierItemSource *source, const QString &operation, QMap<QString, QVariant> &parameters, QObject *parent = nullptr);
     ~StatusNotifierItemJob() override;
 
 protected:
