@@ -195,7 +195,7 @@ void sanity_check( int argc, char* argv[] )
         if (!writeTest(path))
         {
             if (errno == ENOSPC)
-                msg = i18n("Temp directory (%1) is out of disk space.");
+                msg = i18n("Temp directory (%1) is out of disk space.", QFile::decodeName(path));
             else
                 msg = i18n("Writing to the temp directory (%2) failed with\n    "
                            "the error '%1'", QString::fromLocal8Bit(strerror(errno)), QFile::decodeName(path));
@@ -205,9 +205,9 @@ void sanity_check( int argc, char* argv[] )
     {
         path += "/.ICE-unix";
         if (access(path.data(), W_OK) && (errno != ENOENT))
-            msg = i18n("No write access to '%1'.");
+            msg = i18n("No write access to '%1'.", QFile::decodeName(path));
         else if (access(path.data(), R_OK) && (errno != ENOENT))
-            msg = i18n("No read access to '%1'.");
+            msg = i18n("No read access to '%1'.", QFile::decodeName(path));
     }
     if (!msg.isEmpty())
     {
