@@ -46,7 +46,6 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <KPackage/PackageLoader>
 
 #include <KAuthorized>
-#include <KIconLoader>
 #include <KLocalizedString>
 #include <KUser>
 #include <Solid/PowerManagement>
@@ -127,7 +126,7 @@ KSMShutdownDlg::KSMShutdownDlg(QWindow* parent,
     context->setContextProperty(QStringLiteral("spdMethods"), mapSpdMethods);
     context->setContextProperty(QStringLiteral("canLogout"), KAuthorized::authorize(QStringLiteral("logout")));
 
-    // Trying to access a non-existant context property throws an error, always create the property and then update it later
+    // Trying to access a non-existent context property throws an error, always create the property and then update it later
     context->setContextProperty("rebootToFirmwareSetup", false);
 
     QDBusMessage message = QDBusMessage::createMethodCall(s_login1Service, s_login1Path, s_dbusPropertiesInterface, QStringLiteral("Get"));
