@@ -492,7 +492,7 @@ QRect PanelView::geometryByDistance(int distance) const
     case Plasma::Types::RightEdge:
         switch (m_alignment) {
         case Qt::AlignCenter:
-            // Never use rect.right(); for historical reasons it returns left() + width() - 1; see http://doc.qt.io/qt-5/qrect.html#right
+            // Never use rect.right(); for historical reasons it returns left() + width() - 1; see https://doc.qt.io/qt-5/qrect.html#right
             position = QPoint(QPoint(screenGeometry.x() + screenGeometry.width(), screenGeometry.center().y()) - QPoint(thickness() + distance, 0) + QPoint(0, m_offset - height()/2));
             break;
         case Qt::AlignRight:
@@ -566,7 +566,7 @@ void PanelView::restore()
     }
 
     // All the defaults are based on whatever are the current values
-    // so won't be weirdly resetted after screen resolution change
+    // so won't be weirdly reset after screen resolution change
 
     //alignment is not resolution dependent
     //but if fails read it from the resolution dependent one as
@@ -577,7 +577,7 @@ void PanelView::restore()
     // All the other values are read from screen independent values,
     // but fallback on the screen independent section, as is the only place
     // is safe to directly write during plasma startup, as there can be 
-    // resolutoin changes
+    // resolution changes
     m_offset = readConfigValueWithFallBack("offset", m_offset);
     if (m_alignment != Qt::AlignCenter) {
         m_offset = qMax(0, m_offset);
@@ -903,7 +903,7 @@ bool PanelView::event(QEvent *e)
             if (!containmentContainsPosition(we->pos())) {
                 auto we2 = new QWheelEvent(positionAdjustedForContainment(we->pos()),
                                 positionAdjustedForContainment(we->pos()) + position(),
-                                we->pixelDelta(), we->angleDelta(), we->delta(),
+                                we->pixelDelta(), we->angleDelta(), we->angleDelta().y(),
                                 we->orientation(), we->buttons(), we->modifiers(), we->phase());
 
                 QCoreApplication::postEvent(this, we2);
