@@ -34,7 +34,7 @@ class ScreenPool : public QObject, public QAbstractNativeEventFilter
     Q_OBJECT
 
 public:
-    ScreenPool(KSharedConfig::Ptr config, QObject *parent = nullptr);
+    explicit ScreenPool(const KSharedConfig::Ptr &config, QObject *parent = nullptr);
     void load();
     ~ScreenPool() override;
 
@@ -53,7 +53,7 @@ public:
     QList <int> knownIds() const;
 
 protected:
-    bool nativeEventFilter(const QByteArray & eventType, void * message, long * result) Q_DECL_OVERRIDE;
+    bool nativeEventFilter(const QByteArray & eventType, void * message, long * result) override;
 
 private:
     void save();
@@ -65,6 +65,7 @@ private:
     QHash<QString, int> m_idForConnector;
 
     QTimer m_configSaveTimer;
+    int m_xrandrExtensionOffset;
 };
 
 #endif // SCREENPOOL_H
