@@ -1,6 +1,7 @@
 /*
  * Holds one embedded window, registers as DBus entry
  * Copyright (C) 2015 <davidedmundson@kde.org> David Edmundson
+ * Copyright (C) 2019 <materka@gmail.com> Konrad Materka
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -20,6 +21,7 @@
 
 #include "sniproxy.h"
 
+#include <algorithm>
 #include <xcb/xcb.h>
 #include <xcb/xcb_atom.h>
 #include <xcb/xcb_event.h>
@@ -49,6 +51,7 @@
 #define SNI_WATCHER_PATH "/StatusNotifierWatcher"
 
 static uint16_t s_embedSize = 32; //max size of window to embed. We no longer resize the embedded window as Chromium acts stupidly.
+static unsigned int XEMBED_VERSION = 0;
 
 int SNIProxy::s_serviceCount = 0;
 
@@ -77,6 +80,7 @@ SNIProxy::SNIProxy(xcb_window_t wid, QObject* parent):
     //instead lets use one DBus connection per SNI
     m_dbus(QDBusConnection::connectToBus(QDBusConnection::SessionBus, QStringLiteral("XembedSniProxy%1").arg(s_serviceCount++))),
     m_windowId(wid),
+    sendingClickEvent(false),
     m_injectMode(Direct)
 {
     //create new SNI
@@ -95,10 +99,13 @@ SNIProxy::SNIProxy(xcb_window_t wid, QObject* parent):
     //create a container window
     auto screen = xcb_setup_roots_iterator (xcb_get_setup (c)).data;
     m_containerWid = xcb_generate_id(c);
-    uint32_t values[2];
-    auto mask = XCB_CW_BACK_PIXEL | XCB_CW_OVERRIDE_REDIRECT;
+    uint32_t values[3];
+    uint32_t mask = XCB_CW_BACK_PIXEL | XCB_CW_OVERRIDE_REDIRECT | XCB_CW_EVENT_MASK;
     values[0] = screen->black_pixel; //draw a solid background so the embedded icon doesn't get garbage in it
     values[1] = true; //bypass wM
+    values[2] = XCB_EVENT_MASK_VISIBILITY_CHANGE | // receive visibility change, to handle KWin restart #357443
+                // Redirect and handle structure (size, position) requests from the embedded window.
+                XCB_EVENT_MASK_STRUCTURE_NOTIFY | XCB_EVENT_MASK_SUBSTRUCTURE_NOTIFY | XCB_EVENT_MASK_SUBSTRUCTURE_REDIRECT;
     xcb_create_window (c,                          /* connection    */
                     XCB_COPY_FROM_PARENT,          /* depth         */
                      m_containerWid,               /* window Id     */
@@ -148,7 +155,7 @@ SNIProxy::SNIProxy(xcb_window_t wid, QObject* parent):
     xcb_change_save_set(c, XCB_SET_MODE_INSERT, wid);
 
     //tell client we're embedding it
-    xembed_message_send(wid, XEMBED_EMBEDDED_NOTIFY, m_containerWid, 0, 0);
+    xembed_message_send(wid, XEMBED_EMBEDDED_NOTIFY, 0, m_containerWid, XEMBED_VERSION);
 
     //move window we're embedding
     const uint32_t windowMoveConfigVals[2] = { 0, 0 };
@@ -213,11 +220,27 @@ void SNIProxy::update()
     emit NewToolTip();
 }
 
-void SNIProxy::stackContainerWindow(const uint32_t stackMode) const
+void SNIProxy::resizeWindow(const uint16_t width, const uint16_t height) const
 {
-    auto c = QX11Info::connection();
-    const uint32_t stackData[] = {stackMode};
-    xcb_configure_window(c, m_containerWid, XCB_CONFIG_WINDOW_STACK_MODE, stackData);
+    auto connection = QX11Info::connection();
+
+    uint16_t widthNormalized = std::min(width, s_embedSize);
+    uint16_t heighNormalized = std::min(height, s_embedSize);
+
+    const uint32_t windowSizeConfigVals[2] = { widthNormalized, heighNormalized };
+    xcb_configure_window(connection, m_windowId,
+                         XCB_CONFIG_WINDOW_WIDTH | XCB_CONFIG_WINDOW_HEIGHT,
+                         windowSizeConfigVals);
+
+    xcb_flush(connection);
+}
+
+void SNIProxy::hideContainerWindow(xcb_window_t windowId) const
+{
+    if (m_containerWid == windowId && !sendingClickEvent) {
+        qDebug() << "Container window visible, stack below";
+        stackContainerWindow(XCB_STACK_MODE_BELOW);
+    }
 }
 
 QSize SNIProxy::calculateClientWindowSize() const
@@ -239,19 +262,7 @@ QSize SNIProxy::calculateClientWindowSize() const
     if (clientWindowSize.isEmpty() || clientWindowSize.width() > s_embedSize || clientWindowSize.height() > s_embedSize) {
         qCDebug(SNIPROXY) << "Resizing window" << m_windowId << Title() << "from w*h" << clientWindowSize;
 
-        xcb_configure_notify_event_t event;
-        memset(&event, 0x00, sizeof(xcb_configure_notify_event_t));
-        event.response_type = XCB_CONFIGURE_NOTIFY;
-        event.event = m_windowId;
-        event.window = m_windowId;
-        event.width = s_embedSize;
-        event.height = s_embedSize;
-        xcb_send_event(c, false, m_windowId, XCB_EVENT_MASK_STRUCTURE_NOTIFY, (char *) &event);
-
-        const uint32_t windowMoveConfigVals[2] = { s_embedSize, s_embedSize };
-        xcb_configure_window(c, m_windowId,
-                             XCB_CONFIG_WINDOW_WIDTH | XCB_CONFIG_WINDOW_HEIGHT,
-                             windowMoveConfigVals);
+        resizeWindow(s_embedSize, s_embedSize);
 
         clientWindowSize = QSize(s_embedSize, s_embedSize);
     }
@@ -425,6 +436,13 @@ QPoint SNIProxy::calculateClickPoint() const
     return clickPoint;
 }
 
+void SNIProxy::stackContainerWindow(const uint32_t stackMode) const
+{
+    auto c = QX11Info::connection();
+    const uint32_t stackData[] = {stackMode};
+    xcb_configure_window(c, m_containerWid, XCB_CONFIG_WINDOW_STACK_MODE, stackData);
+}
+
 //____________properties__________
 
 QString SNIProxy::Category() const
@@ -506,6 +524,7 @@ void SNIProxy::sendClick(uint8_t mouseButton, int x, int y)
     //ideally we should make this match the plasmoid hit area
 
     qCDebug(SNIPROXY) << "Received click" << mouseButton << "with passed x*y" << x << y;
+    sendingClickEvent = true;
 
     auto c = QX11Info::connection();
 
@@ -596,4 +615,6 @@ void SNIProxy::sendClick(uint8_t mouseButton, int x, int y)
 #ifndef VISUAL_DEBUG
     stackContainerWindow(XCB_STACK_MODE_BELOW);
 #endif
+
+    sendingClickEvent = false;
 }
